@@ -1,8 +1,8 @@
 createDemandSite.base <-
-function(name,label,demandTS,demandParams,returnFlowFraction,suppliers,downstream,priority)
+function(name,demandTS,demandParams,returnFlowFraction,suppliers,downstream,priority)
 {
    demand<-list(name=name,
-                label=label,
+                label=runif(1),
                 demandTS=demandTS,
                 demandParams=demandParams,
                 returnFlowFraction=returnFlowFraction,
